%define anolis_release 5
# Recognize terminal size
%bcond_without perl_Term_Table_enables_terminal
# Respect Unicode rules when breaking lines
%bcond_without perl_Term_Table_enables_unicode

%global __requires_exclude %{?__requires_exclude:%{__requires_exclude}|}^perl\\(Importer\\)$

Name:           perl-Term-Table
Version:        0.016
Release: %{anolis_release}%{dist}
Summary:        Format a header and rows into a table
License:        GPL+ or Artistic
URL:            https://metacpan.org/release/Term-Table
Source0:        https://cpan.metacpan.org/authors/id/E/EX/EXODIST/Term-Table-%{version}.tar.gz
# Unbundle Object::HashBase
Patch0:         Term-Table-0.016-Use-system-Object-HashBase.patch
BuildRequires:  make
BuildRequires:  perl(Carp)
BuildRequires:  perl(Config)
BuildRequires:  perl(strict)
BuildRequires:  perl(warnings)
BuildRequires:  perl-generators
BuildRequires:  perl-interpreter
BuildRequires:  perl(List::Util)
BuildRequires:  perl(Scalar::Util)
BuildRequires:  perl(:VERSION) >= 5.8.1
BuildRequires:  perl(Importer) >= 0.024
BuildRequires:  perl(Object::HashBase) >= 0.008
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.76
%if %{with perl_Term_Table_enables_terminal}
BuildRequires:  perl(Term::Size::Any) >= 0.002
%endif
%if %{with perl_Term_Table_enables_unicode}
BuildRequires:  perl(Unicode::GCString) >= 2013.10
%endif
BuildRequires:  perl(base)
BuildRequires:  perl(utf8)
BuildRequires:  perl(Test2::API)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test2::Tools::Tiny) >= 1.302097

Requires:       perl(Importer) >= 0.024
%if %{with perl_Term_Table_enables_terminal}
Suggests:       perl(Term::ReadKey) >= 2.32
# Prefer Term::Size::Any over Term::ReadKey
Recommends:     perl(Term::Size::Any) >= 0.002
%endif
%if %{with perl_Term_Table_enables_unicode}
Recommends:     perl(Unicode::GCString) >= 2013.10
%endif
BuildArch:      noarch

%description
Perl-Term-Table is a Perl module that provides a simple way to output tabular
data in a terminal/console. It is designed to make it easy to display data in a
formatted table with columns and rows, making it easier to read and understand.
This module can be used to generate tables in various formats such as ASCII,
HTML, and CSV.

Perl-Term-Table provides a simple API for generating tables. You can customize
the table's appearance, including column headers, row borders, and cell padding.
The API is highly configurable, allowing you to specify the width of each
column, the alignment of text within each cell, and the color of the table's
borders.

This module is highly flexible and can accept data from various sources such as
arrays, hashes, and SQL databases, making it ideal for generating tables from
different data sources. It can also output tables to different destinations such
as a file or a web page.

The Perl-Term-Table module is easy to install using the CPAN command or by
downloading it directly from the Perl-Term-Table GitHub repository. Once
installed, you can use it in your Perl scripts to generate tables with ease.

To generate a table using Perl-Term-Table, first, you need to create a table
object. You can specify the number of columns and their widths using the
add_columns method. You can also set the table's caption, header, and footer
using the caption, header, and footer methods.

Next, you can add data to the table using the add_row method. You can add a
single row of data or an array of rows. Finally, you can output the table using
the render method. By default, the table is output in ASCII format, but you can
also specify HTML or CSV format using the format parameter.

In summary, Perl-Term-Table is a powerful and flexible module for generating
tables in various formats. It provides a simple API that is highly configurable,
making it easy to customize the appearance of your tables. It can also accept
data from various sources, making it ideal for generating tables from different
data sources.

%package tests
Summary:        Tests for %{name}
Requires:       %{name} = %{EVR}
Requires:       perl-Test-Harness

%description tests
Tests from %{name}. Execute them
with "%{_libexecdir}/%{name}/test".

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n Term-Table-%{version}
for F in lib/Term/Table/HashBase.pm t/HashBase.t; do
    perl -e 'unlink $ARGV[0] or die $!' "$F"
    perl -i -s -ne 'print $_ unless m{\A\Q$file\E\b}' -- -file="$F" MANIFEST
done
for F in t/*.t t/Table/*.t; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!\s*perl}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%{make_build}

%install
%{make_install}
# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a t %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name} && exec prove -r -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test
%{_fixperms} %{buildroot}/*

%check
unset TABLE_TERM_SIZE
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/*
%{_mandir}/man3/*

%files tests
%{_libexecdir}/%{name}

%files doc
%doc Changes README

%changelog 
* Tue Apr 11 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 0.016-4
- Add doc pkg

* Mon Feb 06 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.016-3
- remove versioned MODULE_COMPAT_ requires

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.016-2
- rebuild with perl 5.36.0

* Wed Apr 20 2022 Zhongling He <zhonglingh@linux.alibaba.com> - 0.016-1
- Init package from upstream v0.016
